@@ -7,12 +7,12 @@ taskmaster.cli.master
 """
 
 
-def run(target, reset=False, size=10000, address='tcp://0.0.0.0:3050'):
+def run(target, reset=False, size=10000, address='tcp://0.0.0.0:3050', log_level='INFO'):
     from taskmaster.server import Server, Controller
 
-    server = Server(address, size=size)
+    server = Server(address, size=size, log_level=log_level)
 
-    controller = Controller(server, target)
+    controller = Controller(server, target, log_level=log_level)
     if reset:
         controller.reset()
     controller.start()
@@ -25,6 +25,7 @@ def main():
     parser.add_option("--address", dest="address", default='tcp://127.0.0.1:3050')
     parser.add_option("--size", dest="size", default='10000', type=int)
     parser.add_option("--reset", dest="reset", default=False, action='store_true')
+    parser.add_option("--log-level", dest="log_level", default='INFO')
     (options, args) = parser.parse_args()
     if len(args) != 1:
         print 'Usage: tm-master <callback>'
